A data.frame containing the predictions for spawning stock biomass of Norway Pout, Herring, Cod, and Sole
in the North Sea between 1986-2050 under an MSY fishing scenario from the LeMaRns package.
SSB_lmA data.frame with 65 rows and 4 variables:
N.poutSpawning stock biomass of Norway Pout, in log tonnes.
HerringSpawning stock biomass of Herring, in log tonnes.
CodSpawning stock biomass of Cod, in log tonnes.
SoleSpawning stock biomass of Sole, in log tonnes.
Thorpe, R. B., Le Quesne, W. J. F., Luxford, F., Collie, J. S., and Jennings, S. (2015). Evaluation and management implications of uncertainty in a multispecies size-structured model of population and community responses to fishing. Methods in Ecology and Evolution, 6(1), 49–58.